<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Information on how to translate KeePassX can be found under:</source>
        <translation>KeePassX uygulamasının nasıl çevrileceğine ilişkin bilgileri burada bulabilirsiniz:</translation>
    </message>
    <message>
        <source>Team</source>
        <translation>Takım</translation>
    </message>
    <message>
        <source>Developer, Project Admin</source>
        <translation>Geliştirici, Proje Yöneticisi</translation>
    </message>
    <message>
        <source>Web Designer</source>
        <translation>Web Tasarımı</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Geliştirici</translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation>Teşekkürler</translation>
    </message>
    <message>
        <source>Patches for better MacOS X support</source>
        <translation>Daha iyi MacOS X desteği için yamalar</translation>
    </message>
    <message>
        <source>Main Application Icon</source>
        <translation>Ugulamanın Simgesi</translation>
    </message>
    <message>
        <source>Various fixes and improvements</source>
        <translation>Çeşitli hata düzeltmeleri ve geliştirmeler</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>&apos;%1&apos; dosyası bulunamadı.</translation>
    </message>
    <message>
        <source>Make sure that the program is installed correctly.</source>
        <translation>Uygulamanın doğru yüklendiğinden emin olun.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <source>Current Translation</source>
        <translation>Şimdiki Çeviri</translation>
    </message>
    <message>
        <source>None</source>
        <comment>Please replace &apos;None&apos; with the language of your translation</comment>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Serdar Soytetir</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>AppName</source>
        <translation>AppName</translation>
    </message>
    <message>
        <source>AppFunc</source>
        <translation>AppFunc</translation>
    </message>
    <message>
        <source>http://keepassx.sourceforge.net</source>
        <translation>http://keepassx.sourceforge.net</translation>
    </message>
    <message>
        <source>keepassx@gmail.com</source>
        <translation>keepassx@gmail.com</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Katkıda Bulunanlar</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Yerelleştirme</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX is distributed under the terms of the
General Public License (GPL) version 2.</source>
        <translation>Copyright (C) 2005 - 2009 KeePassX Takımı
KeePassX Genel Kamu Lisansı&apos;nın 2. sürümü
ile dağıtılmaktadır.</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Yer İmi Ekle</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Dosya:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Gözat...</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Yer İmini Düzenle</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePassX Veritabanları (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
</context>
<context>
    <name>AutoTypeDlg</name>
    <message>
        <source>KeePassX - Auto-Type</source>
        <translation>KeePassX - Otomatik-Tip</translation>
    </message>
    <message>
        <source>Click on an entry to auto-type it.</source>
        <translation>Bir girdiyi otomatik-tip yapmak için üzerine tıklayın.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı Adı</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Otomatik-Tip</translation>
    </message>
</context>
<context>
    <name>CDbSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>AES(Rijndael):  256 Bit   (default)</source>
        <translation>AES(Rijndael):  256 Bit   (öntanımlı)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation> Twofish:  256 Bit</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Please determine the number of encryption rounds.</source>
        <translation>Lütfen şifrelemenin kaç basamak ile yapılacağını belirtin.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is not valid integer value.</source>
        <translation>&apos;%1&apos; geçerli bir tam sayı değeri değil.</translation>
    </message>
    <message>
        <source>The number of encryption rounds have to be greater than 0.</source>
        <translation>Sıfırdan büyük olması gereken ve şifrelemenin kaç basamaklı olacağını belirten sayı.</translation>
    </message>
</context>
<context>
    <name>CEditEntryDlg</name>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>1 Week</source>
        <translation>1 Hafta</translation>
    </message>
    <message>
        <source>2 Weeks</source>
        <translation>1 Hafta</translation>
    </message>
    <message>
        <source>3 Weeks</source>
        <translation>3 Hafta</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 Ay</translation>
    </message>
    <message>
        <source>3 Months</source>
        <translation>3 Ay</translation>
    </message>
    <message>
        <source>6 Months</source>
        <translation>6 Ay</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 Yıl</translation>
    </message>
    <message>
        <source>Calendar...</source>
        <translation>Takvim...</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bit</translation>
    </message>
    <message>
        <source>Edit Entry</source>
        <translation>Girdiyi Düzenle</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Password and password repetition are not equal.
Please check your input.</source>
        <translation>Parola ve parola tekrarı birbirini tutmuyor.
Lütfen girdilerinizi kontrol edin.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <source>[Untitled Entry]</source>
        <translation>[Başlıksız Girdi]</translation>
    </message>
    <message>
        <source>Add Attachment...</source>
        <translation>Eklenti Ekle...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Could not open file.</source>
        <translation>Dosya açılamadı.</translation>
    </message>
    <message>
        <source>The chosen entry has no attachment or it is empty.</source>
        <translation>Seçilen girdinin eklentisi yok ya da boş.</translation>
    </message>
    <message>
        <source>Save Attachment...</source>
        <translation>Eklentiyi kaydet...</translation>
    </message>
    <message>
        <source>Error while writing the file.</source>
        <translation>Dosya yazılırken hata.</translation>
    </message>
    <message>
        <source>Delete Attachment?</source>
        <translation>Eklenti silinsin mi?</translation>
    </message>
    <message>
        <source>You are about to delete the attachment of this entry.
Are you sure?</source>
        <translation>Bu girdinin eklentisini silmek üzeresiniz.
Emin misiniz?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No, Cancel</source>
        <translation>Hayır, İptal Et</translation>
    </message>
    <message>
        <source>New Entry</source>
        <translation>Yeni Girdi</translation>
    </message>
</context>
<context>
    <name>CGenPwDialog</name>
    <message>
        <source>Password Generator</source>
        <translation>Parola Oluşturucu</translation>
    </message>
    <message>
        <source>%1 Bits</source>
        <translation>%1 Bit</translation>
    </message>
</context>
<context>
    <name>CSelectIconDlg</name>
    <message>
        <source>Replace...</source>
        <translation>Değiştir...</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Add Custom Icon</source>
        <translation>Özel Simge Ekle</translation>
    </message>
    <message>
        <source>Pick</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>Add Icons...</source>
        <translation>Simge Ekle...</translation>
    </message>
    <message>
        <source>Images (%1)</source>
        <translation>Resimler (%1)</translation>
    </message>
    <message>
        <source>%1: File could not be loaded.</source>
        <translation>%1: Dosya yüklenemedi.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>An error occured while loading the icon(s):</source>
        <translation>Simgeler yüklenirken bir hata oluştu:</translation>
    </message>
    <message>
        <source>An error occured while loading the icon.</source>
        <translation>Simge yüklenirken bir hata oluştu.</translation>
    </message>
</context>
<context>
    <name>CSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Select a directory...</source>
        <translation>Bir dizin seçin...</translation>
    </message>
    <message>
        <source>Select an executable...</source>
        <translation>Bir çalıştırılabilir dosya seçin...</translation>
    </message>
    <message>
        <source>System Language</source>
        <translation type="unfinished">Sistem Dili</translation>
    </message>
</context>
<context>
    <name>CalendarDialog</name>
    <message>
        <source>Calendar</source>
        <translation>Takvim</translation>
    </message>
</context>
<context>
    <name>CollectEntropyDlg</name>
    <message>
        <source>Random Number Generator</source>
        <translation>Rastgele Sayı Oluşturucu</translation>
    </message>
    <message>
        <source>Collecting entropy...
Please move the mouse and/or press some keys until enought entropy for a reseed of the random number generator is collected.</source>
        <translation>Atıl enerji toplanıyor...
Rastgele sayı oluşturucudan yeterli atıl enerji toplanırken fareyi oynatın ya da rastgele tuşlara basın.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Random pool successfully reseeded!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Rastgele havuzu başarılı bir şekilde yeniden oluşturuldu!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Entropy Collection</source>
        <translation>Enerji Toplama</translation>
    </message>
</context>
<context>
    <name>CustomizeDetailViewDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>Rich Text Editor</source>
        <translation>Zengin Metin Düzenleyici</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <source>B</source>
        <translation>K</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Yatık</translation>
    </message>
    <message>
        <source>I</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>Underlined</source>
        <translation>Altı çizgili</translation>
    </message>
    <message>
        <source>U</source>
        <translation>A</translation>
    </message>
    <message>
        <source>Left-Aligned</source>
        <translation>Sola-Dayalı</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Ortalanmış</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>Right-Aligned</source>
        <translation>Sağa-Dayalı</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Justified</source>
        <translation>İki Tarafa Dayalı</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Metin Rengi</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Yazı Tipi Boyutu</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <source>78</source>
        <translation>78</translation>
    </message>
    <message>
        <source>Templates</source>
        <translation>Şablonlar</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı Adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Yorum Satırı Yap</translation>
    </message>
    <message>
        <source>Attachment Name</source>
        <translation>Eklenti Adı</translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation>Oluşturulma Tarihi</translation>
    </message>
    <message>
        <source>Last Access Date</source>
        <translation>Son Erişim Tarihi</translation>
    </message>
    <message>
        <source>Last Modification Date</source>
        <translation>Son Değiştirilme Tarihi</translation>
    </message>
    <message>
        <source>Expiration Date</source>
        <translation>Süre Dolumu Tarihi</translation>
    </message>
    <message>
        <source>Time till Expiration</source>
        <translation>Süre Dolumuna Kalan Süre</translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <source>Never</source>
        <translation>Asla</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsDlg</name>
    <message>
        <source>Database Settings</source>
        <translation>Veritabanı Ayarları</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Şifreleme</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritma:</translation>
    </message>
    <message>
        <source>Encryption Rounds:</source>
        <translation>Şifreleme Basamağı:</translation>
    </message>
    <message>
        <source>Calculate rounds for a 1-second delay on this computer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailViewTemplate</name>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı Adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Oluşturulma</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Son Erişim</translation>
    </message>
    <message>
        <source>Last Modification</source>
        <translation>Son Değiştirilme</translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation>Süre Dolumu</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Yorum Satırı Yap</translation>
    </message>
</context>
<context>
    <name>EditEntryDialog</name>
    <message>
        <source>Edit Entry</source>
        <translation>Girdiyi Düzenle</translation>
    </message>
    <message>
        <source>Ge&amp;n.</source>
        <translation>Olu&amp;ştur.</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kalite:</translation>
    </message>
    <message>
        <source>Attachment:</source>
        <translation>Eklenti:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grup:</translation>
    </message>
    <message>
        <source>Password Repet.:</source>
        <translation type="obsolete">Parola (Yeniden):</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <source>Expires:</source>
        <translation>Süre Dolumu:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Asla</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bit</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroupDialog</name>
    <message>
        <source>Group Properties</source>
        <translation>Grup Özellikleri</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
</context>
<context>
    <name>ExpiredEntriesDialog</name>
    <message>
        <source>Expired Entries</source>
        <translation>Süresi Dolmuş Girdiler</translation>
    </message>
    <message>
        <source>Double click on an entry to jump to it.</source>
        <translation>Bir girdiye geçmek için üzerine çift tıklayın.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı Adı</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Süresi Dolmuş</translation>
    </message>
    <message>
        <source>Expired Entries in the Database</source>
        <translation>Veritabanındaki Dolmuş Girdiler</translation>
    </message>
</context>
<context>
    <name>Export_KeePassX_Xml</name>
    <message>
        <source>KeePassX XML File</source>
        <translation>KeePassX XML Dosyası</translation>
    </message>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML Dosyaları (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
</context>
<context>
    <name>Export_Txt</name>
    <message>
        <source>Text File</source>
        <translation>Metin Dosyası</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Text Files (*.txt)</source>
        <translation>Metin Dosyaları (*.txt)</translation>
    </message>
</context>
<context>
    <name>ExporterBase</name>
    <message>
        <source>Export Failed</source>
        <translation>Dışarıya Aktarma İşlemi Başarısız Oldu</translation>
    </message>
    <message>
        <source>Export File...</source>
        <translation>Dosyaya Aktar...</translation>
    </message>
</context>
<context>
    <name>FileErrors</name>
    <message>
        <source>No error occurred.</source>
        <translation>Hiç hata oluşmadı.</translation>
    </message>
    <message>
        <source>An error occurred while reading from the file.</source>
        <translation>Dosyadan okunurken bir hata oluştu.</translation>
    </message>
    <message>
        <source>An error occurred while writing to the file.</source>
        <translation>Dosyaya yazılırken bir hata oluştu.</translation>
    </message>
    <message>
        <source>A fatal error occurred.</source>
        <translation>Sonlandırıcı bir hata oluştu.</translation>
    </message>
    <message>
        <source>An resource error occurred.</source>
        <translation>Bir kaynak hatası oluştu.</translation>
    </message>
    <message>
        <source>The file could not be opened.</source>
        <translation>Dosya açılamadı.</translation>
    </message>
    <message>
        <source>The operation was aborted.</source>
        <translation>İşlem sonlandırıldı.</translation>
    </message>
    <message>
        <source>A timeout occurred.</source>
        <translation>Bir zaman aşımı oluştu.</translation>
    </message>
    <message>
        <source>An unspecified error occurred.</source>
        <translation>Belirtilmemiş hata oluştu.</translation>
    </message>
    <message>
        <source>The file could not be removed.</source>
        <translation>Dosya silinemedi.</translation>
    </message>
    <message>
        <source>The file could not be renamed.</source>
        <translation>Dosya yeniden adlandırılamadı.</translation>
    </message>
    <message>
        <source>The position in the file could not be changed.</source>
        <translation>Dosyanın içerisindeki konum değiştirilemedi.</translation>
    </message>
    <message>
        <source>The file could not be resized.</source>
        <translation>Dosya yeniden boyutlandırılamadı.</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Dosyaya erişilemedi.</translation>
    </message>
    <message>
        <source>The file could not be copied.</source>
        <translation>Dosya kopyalanamadı.</translation>
    </message>
</context>
<context>
    <name>GenPwDlg</name>
    <message>
        <source>Password Generator</source>
        <translation>Parola Oluşturucu</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Use follo&amp;wing character groups:</source>
        <translation type="obsolete">&amp;Şu karakter gruplarını kullan:</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+W</translation>
    </message>
    <message>
        <source>&amp;Lower Letters</source>
        <translation>&amp;Küçük Harfler</translation>
    </message>
    <message>
        <source>Alt+L</source>
        <translation type="obsolete">Alt+L</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Numbers</source>
        <translation>Raka&amp;mlar</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Upper Letters</source>
        <translation>&amp;Büyük Harfler</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Special Characters</source>
        <translation>Ö&amp;zel Karakterler</translation>
    </message>
    <message>
        <source>Use &amp;only following characters:</source>
        <translation type="obsolete">Sadece bu karak&amp;terleri kullan:</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Uzunluk:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kalite:</translation>
    </message>
    <message>
        <source>Enable entropy collection</source>
        <translation>Enerji toplamayı etkinleştir</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="obsolete">Alt+M</translation>
    </message>
    <message>
        <source>Collect only once per session</source>
        <translation>Her oturum için bir kere topla</translation>
    </message>
    <message>
        <source>New Password:</source>
        <translation>Yeni Parola:</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Oluştur</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Rastgele</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Altı &amp;çizili</translation>
    </message>
    <message>
        <source>&amp;White Spaces</source>
        <translation>Beyaz Alanla&amp;r</translation>
    </message>
    <message>
        <source>&amp;Minus</source>
        <translation>&amp;Eksi</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Buna benzer karakterleri hariç tut</translation>
    </message>
    <message>
        <source>Ensure that password contains characters from every group</source>
        <translation>Parolanın her gruptan karakter içerdiğinden emin olun</translation>
    </message>
    <message>
        <source>Pronounceable</source>
        <translation>Okunabilir</translation>
    </message>
    <message>
        <source>Lower Letters</source>
        <translation>Küçük Harfler</translation>
    </message>
    <message>
        <source>Upper Letters</source>
        <translation>Büyük Harfler</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Rakamlar</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Özel Karakterler</translation>
    </message>
    <message>
        <source>Use following character groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the following characters:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpDlg</name>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Import_KWalletXml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML Dosyaları (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>İçeri Aktarma Başarısız Oldu</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Geçersiz XML verisi (detaylar için stdout çıktısına bakın).</translation>
    </message>
    <message>
        <source>Invalid XML file.</source>
        <translation>Geçersiz XML dosyası.</translation>
    </message>
    <message>
        <source>Document does not contain data.</source>
        <translation>Belge veri içermiyor.</translation>
    </message>
</context>
<context>
    <name>Import_KeePassX_Xml</name>
    <message>
        <source>KeePass XML Files (*.xml)</source>
        <translation>KeePassX XML Dosyaları (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>İçeri Aktarma Başarısız Oldu</translation>
    </message>
    <message>
        <source>XML parsing error on line %1 column %2:
%3</source>
        <translation>Satır %1 sütun %2 konumunda XML ayrıştırma hatası:
%3</translation>
    </message>
    <message>
        <source>Parsing error: File is no valid KeePassX XML file.</source>
        <translation>Ayrıştırma hatası: Dosya geçerli bir KeePassX XML dosyası değil.</translation>
    </message>
</context>
<context>
    <name>Import_PwManager</name>
    <message>
        <source>PwManager Files (*.pwm)</source>
        <translation>PwManager Dosyaları (*.pwm)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>İçeri Aktarma Başarısız Oldu</translation>
    </message>
    <message>
        <source>File is empty.</source>
        <translation>Dosya boş.</translation>
    </message>
    <message>
        <source>File is no valid PwManager file.</source>
        <translation>Dosya geçerli bir PwManager dosyası değil.</translation>
    </message>
    <message>
        <source>Unsupported file version.</source>
        <translation>Desteklenmeyen dosya sürümü.</translation>
    </message>
    <message>
        <source>Unsupported hash algorithm.</source>
        <translation>Desteklenmeyen özet algoritması.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Desteklenmeyen şifreleme algoritması.</translation>
    </message>
    <message>
        <source>Compressed files are not supported yet.</source>
        <translation>Sıkıştırılmış dosyalar henüz desteklenmiyor.</translation>
    </message>
    <message>
        <source>Wrong password.</source>
        <translation>Yanlış parola.</translation>
    </message>
    <message>
        <source>File is damaged (hash test failed).</source>
        <translation>Dosya bozulmuş (özet testi başarısız oldu).</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Geçersiz XML verisi (detaylar için stdout çıktısına bakın).</translation>
    </message>
</context>
<context>
    <name>ImporterBase</name>
    <message>
        <source>Import File...</source>
        <translation>İçeriye Dosya Aktar...</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>İçeri Aktarma Başarısız Oldu</translation>
    </message>
</context>
<context>
    <name>Kdb3Database</name>
    <message>
        <source>Could not open file.</source>
        <translation>Dosya açılamadı.</translation>
    </message>
    <message>
        <source>Unexpected file size (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</source>
        <translation>Beklenmeyen dosya boyutu (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</translation>
    </message>
    <message>
        <source>Wrong Signature</source>
        <translation>Yanlış İmza</translation>
    </message>
    <message>
        <source>Unsupported File Version.</source>
        <translation>Desteklenmeyen Dosya Sürümü.</translation>
    </message>
    <message>
        <source>Unknown Encryption Algorithm.</source>
        <translation>Bilinmeyen Şifreleme Algoritması.</translation>
    </message>
    <message>
        <source>Decryption failed.
The key is wrong or the file is damaged.</source>
        <translation>Şifre çözme işlemi başarısız.
Anahtar yanlış ya da dosya bozuk.</translation>
    </message>
    <message>
        <source>Hash test failed.
The key is wrong or the file is damaged.</source>
        <translation>Özet kontrolü başarısız.
Anahtar yanlış ya da dosya bozulmuş.</translation>
    </message>
    <message>
        <source>Unexpected error: Offset is out of range.</source>
        <translation>Beklenmeyen hata: Konum dışı.</translation>
    </message>
    <message>
        <source>Invalid group tree.</source>
        <translation>Geçersiz grup ağacı.</translation>
    </message>
    <message>
        <source>Key file is empty.</source>
        <translation>Anahtar dosyası boş.</translation>
    </message>
    <message>
        <source>The database must contain at least one group.</source>
        <translation>Veritabanı en az bir grup içermelidir.</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">Yazmak için açılamadı.</translation>
    </message>
    <message>
        <source>Unable to initalize the twofish algorithm.</source>
        <translation type="obsolete">Twofish algoritması başlatılamadı.</translation>
    </message>
    <message>
        <source>Unable to initialize the twofish algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown encryption algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database has been opened read-only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kdb3Database::EntryHandle</name>
    <message>
        <source>Bytes</source>
        <translation>Bayt</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>KeepassEntryView</name>
    <message>
        <source>Delete?</source>
        <translation>Silinsin mi?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>At least one group must exist before adding an entry.</source>
        <translation>Bir girdi eklenmeden önce en az bir grup olmalıdır.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı Adı</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Comments</source>
        <translation>Yorumlar</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Süre Dolumu</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Oluşturulma</translation>
    </message>
    <message>
        <source>Last Change</source>
        <translation>Son Değişiklik</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Son Erişim</translation>
    </message>
    <message>
        <source>Attachment</source>
        <translation>Eklenti</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this entry?</source>
        <translation>Bu girdiyi silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete these %1 entries?</source>
        <translation>Bu %1 girdiyi silmek istediğinizden emin misiniz?</translation>
    </message>
</context>
<context>
    <name>KeepassGroupView</name>
    <message>
        <source>Search Results</source>
        <translation>Arama Sonuçları</translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation>Silinsin mi?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all its child groups and all their entries?</source>
        <translation>Bu grubu silmek istediğinizden emin misiniz, tüm alt gruplar ve girdileri de silinecek?</translation>
    </message>
</context>
<context>
    <name>KeepassMainWindow</name>
    <message>
        <source>Ready</source>
        <translation>Hazır</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="obsolete">Kilitli</translation>
    </message>
    <message>
        <source>Unlocked</source>
        <translation type="obsolete">Kilidi Açılmış</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Shift+Ctrl+S</source>
        <translation>Shift+Ctrl+S</translation>
    </message>
    <message>
        <source>Shift+Ctrl+F</source>
        <translation>Shift+Ctrl+F</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>The database file does not exist.</source>
        <translation>Veritabanı dosyası yok.</translation>
    </message>
    <message>
        <source>Loading Database...</source>
        <translation>Veritabanı Yükleniyor...</translation>
    </message>
    <message>
        <source>Loading Failed</source>
        <translation>Yükleme Başarısız Oldu</translation>
    </message>
    <message>
        <source>Unknown error while loading database.</source>
        <translation>Veritabanı yüklenirken bilinmeyen bir hata oluştu.</translation>
    </message>
    <message>
        <source>The following error occured while opening the database:</source>
        <translation>Veritabanı açılırken şu hata oluştu:</translation>
    </message>
    <message>
        <source>Save modified file?</source>
        <translation>Değiştirilmiş dosya kaydeilsin mi?</translation>
    </message>
    <message>
        <source>new</source>
        <translation>yeni</translation>
    </message>
    <message>
        <source>Open Database...</source>
        <translation>Veritabanı Aç...</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePassX Veritabanları (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Süresi Dolmuş</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 Ay</translation>
    </message>
    <message>
        <source>%1 Months</source>
        <translation>%1 Ay</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 Yıl</translation>
    </message>
    <message>
        <source>%1 Years</source>
        <translation>%1 Yıl</translation>
    </message>
    <message>
        <source>1 Day</source>
        <translation>1 Gün</translation>
    </message>
    <message>
        <source>%1 Days</source>
        <translation>%1 Gün</translation>
    </message>
    <message>
        <source>less than 1 day</source>
        <translation>1 günden az</translation>
    </message>
    <message>
        <source>Clone Entry</source>
        <translation>Girdiyi İkile</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Girdiyi Sil</translation>
    </message>
    <message>
        <source>Clone Entries</source>
        <translation>Girdileri İkile</translation>
    </message>
    <message>
        <source>Delete Entries</source>
        <translation>Girdileri Sil</translation>
    </message>
    <message>
        <source>File could not be saved.</source>
        <translation>Dosya kaydedilemedi.</translation>
    </message>
    <message>
        <source>Save Database...</source>
        <translation>Veritabanını Kaydet...</translation>
    </message>
    <message>
        <source>Un&amp;lock Workspace</source>
        <translation>Çalışma A&amp;lanının Kilidini Aç</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Çalışma A&amp;lanını Kilitle</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Araç Çubuğunu Göster</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Database locked</source>
        <translation>Veritabanı kilitli</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked.
This means that either someone else has opened the file or KeePassX crashed last time it opened the database.

Do you want to open it anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create database lock file.</source>
        <translation type="unfinished">Veritabanı kilit dosyası oluşturulamadı.</translation>
    </message>
    <message>
        <source>The current file was modified.
Do you want to save the changes?</source>
        <translation>Geçerli dosya üzerinde değişiklikler yapıldı.
Değişiklikleri kaydetmek ister misiniz?</translation>
    </message>
    <message>
        <source>Couldn&apos;t remove database lock file.</source>
        <translation>Veritabanı kilit dosyası silinemedi.</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create lock file. Opening the database read-only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>&apos;%1&apos; dosyası bulunamadı.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">TAMAM</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>KeePassX</source>
        <translation>KeePassX</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Gruplar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <source>&amp;Export to...</source>
        <translation>D&amp;ışarı aktar...</translation>
    </message>
    <message>
        <source>&amp;Import from...</source>
        <translation>&amp;İçeri aktar...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Düzenle</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>E&amp;xtras</source>
        <translation>Daha Fa&amp;zlası</translation>
    </message>
    <message>
        <source>&amp;Open Database...</source>
        <translation>&amp;Veritabanı Aç...</translation>
    </message>
    <message>
        <source>&amp;Close Database</source>
        <translation>Veritabanını &amp;Kapat</translation>
    </message>
    <message>
        <source>&amp;Save Database</source>
        <translation>Veritabanını Kayde&amp;t</translation>
    </message>
    <message>
        <source>Save Database &amp;As...</source>
        <translation>Veritabanını &amp;Farklı Kaydet...</translation>
    </message>
    <message>
        <source>&amp;Database Settings...</source>
        <translation>Veri&amp;tabanı Ayarları...</translation>
    </message>
    <message>
        <source>Change &amp;Master Key...</source>
        <translation>Uygulama Anahtarını De&amp;ğiştir...</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Çalışma A&amp;lanını Kilitle</translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <translation>A&amp;yarlar...</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>H&amp;akkında...</translation>
    </message>
    <message>
        <source>&amp;KeePassX Handbook...</source>
        <translation>&amp;KeePassX El Kitabı...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Gizle</translation>
    </message>
    <message>
        <source>Standard KeePass Single User Database (*.kdb)</source>
        <translation type="obsolete">Standart KeePassX Veritabanı Dosyası (*.kdb)</translation>
    </message>
    <message>
        <source>Advanced KeePassX Database (*.kxdb)</source>
        <translation type="obsolete">Gelişmiş KeePassX Veritabanı Dosyası (*.kxdb)</translation>
    </message>
    <message>
        <source>Recycle Bin...</source>
        <translation>Çöp Kutusu...</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Yer İmleri</translation>
    </message>
    <message>
        <source>Toolbar &amp;Icon Size</source>
        <translation>Araç Çubuğu &amp;Simge Boyutu</translation>
    </message>
    <message>
        <source>&amp;Columns</source>
        <translation>&amp;Sütunlar</translation>
    </message>
    <message>
        <source>&amp;Manage Bookmarks...</source>
        <translation>&amp;Yer İmlerini Yönet...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Edit Group...</source>
        <translation>&amp;Grubu Düzenle...</translation>
    </message>
    <message>
        <source>&amp;Delete Group</source>
        <translation>Grubu &amp;Sil</translation>
    </message>
    <message>
        <source>Copy Password &amp;to Clipboard</source>
        <translation>Parolayı Panoya &amp;Kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;Username to Clipboard</source>
        <translation>Kullanıcı &amp;Adını Panoya Kopyala</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>&amp;Adres Aç</translation>
    </message>
    <message>
        <source>&amp;Save Attachment As...</source>
        <translation>&amp;Eklentiyi Farklı Kaydet...</translation>
    </message>
    <message>
        <source>Add &amp;New Entry...</source>
        <translation>Yeni &amp;Girdi Ekle...</translation>
    </message>
    <message>
        <source>&amp;View/Edit Entry...</source>
        <translation>&amp;Girdiyi Göster/Düzenle...</translation>
    </message>
    <message>
        <source>De&amp;lete Entry</source>
        <translation>Girdiyi &amp;Sil</translation>
    </message>
    <message>
        <source>&amp;Clone Entry</source>
        <translation>Girdiyi &amp;Çoğalt</translation>
    </message>
    <message>
        <source>Search &amp;in Database...</source>
        <translation>&amp;Veritabanında Ara...</translation>
    </message>
    <message>
        <source>Search in this &amp;Group...</source>
        <translation>&amp;Bu Grup içerisinde Ara...</translation>
    </message>
    <message>
        <source>Show &amp;Entry Details</source>
        <translation>&amp;Girdi Ayrıntılarını Göster</translation>
    </message>
    <message>
        <source>Hide &amp;Usernames</source>
        <translation>Kullanıcı &amp;Adlarını Gizle</translation>
    </message>
    <message>
        <source>Hide &amp;Passwords</source>
        <translation>Parolaları &amp;Gizle</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Başlık</translation>
    </message>
    <message>
        <source>User&amp;name</source>
        <translation>&amp;Kullanıcı Adı</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;Adres</translation>
    </message>
    <message>
        <source>&amp;Password</source>
        <translation>&amp;Parola</translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation>&amp;Açıklama</translation>
    </message>
    <message>
        <source>E&amp;xpires</source>
        <translation>&amp;Süre Dolumu</translation>
    </message>
    <message>
        <source>C&amp;reation</source>
        <translation>&amp;Oluşturulma</translation>
    </message>
    <message>
        <source>&amp;Last Change</source>
        <translation>&amp;Son Değişiklik</translation>
    </message>
    <message>
        <source>Last &amp;Access</source>
        <translation>Son &amp;Erişim</translation>
    </message>
    <message>
        <source>A&amp;ttachment</source>
        <translation>&amp;Eklenti</translation>
    </message>
    <message>
        <source>Show &amp;Statusbar</source>
        <translation>&amp;Durum Çubuğunu Göster</translation>
    </message>
    <message>
        <source>&amp;Perform AutoType</source>
        <translation>&amp;Otomatik Tip İyileştirmesi Yap</translation>
    </message>
    <message>
        <source>&amp;16x16</source>
        <translation>&amp;16x16</translation>
    </message>
    <message>
        <source>&amp;22x22</source>
        <translation>&amp;22x22</translation>
    </message>
    <message>
        <source>2&amp;8x28</source>
        <translation>2&amp;8x28</translation>
    </message>
    <message>
        <source>&amp;New Database...</source>
        <translation>&amp;Yeni Veritabanı...</translation>
    </message>
    <message>
        <source>&amp;Password Generator...</source>
        <translation>Parola &amp;Oluşturucu...</translation>
    </message>
    <message>
        <source>&amp;Group (search results only)</source>
        <translation type="obsolete">&amp;Grup (sadece arama sonuçları)</translation>
    </message>
    <message>
        <source>Show &amp;Expired Entries...</source>
        <translation>&amp;Süresi Dolmuş Girdileri Göster...</translation>
    </message>
    <message>
        <source>&amp;Add Bookmark...</source>
        <translation>&amp;Yer İmi Ekle...</translation>
    </message>
    <message>
        <source>Bookmark &amp;this Database...</source>
        <translation>&amp;Bu Veritabanını Yer İmlerine Ekle...</translation>
    </message>
    <message>
        <source>&amp;Add New Subgroup...</source>
        <translation>&amp;Yeni Alt Grup Ekle...</translation>
    </message>
    <message>
        <source>Copy URL to Clipboard</source>
        <translation>Adresi Panoya Kopyala</translation>
    </message>
    <message>
        <source>Add New Group...</source>
        <translation>Yeni Grup Ekle...</translation>
    </message>
    <message>
        <source>&amp;Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageBookmarksDlg</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Yerimlerini Yönet</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Enter Master Key</source>
        <translation>Ana Anahtarı Gir</translation>
    </message>
    <message>
        <source>Set Master Key</source>
        <translation>Ana Anahtarı Ayarla</translation>
    </message>
    <message>
        <source>Change Master Key</source>
        <translation>Ana Anahtarı Değiştir</translation>
    </message>
    <message>
        <source>Database Key</source>
        <translation>Veritabanı Anahtarı</translation>
    </message>
    <message>
        <source>Last File</source>
        <translation>Son Dosya</translation>
    </message>
    <message>
        <source>Select a Key File</source>
        <translation>Anahtar dosyasını Seç</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <source>Key Files (*.key)</source>
        <translation>Key Dosyaları (*.key)</translation>
    </message>
    <message>
        <source>Please enter a Password or select a key file.</source>
        <translation>Lütfen gir parola girin ya da anahtar dosyası seçin.</translation>
    </message>
    <message>
        <source>Please enter a Password.</source>
        <translation>Lütfen bir parola girin.</translation>
    </message>
    <message>
        <source>Please provide a key file.</source>
        <translation>Lütfen bir key dosyası girin.</translation>
    </message>
    <message>
        <source>%1:
No such file or directory.</source>
        <translation>%1:
Böyle bir dosya ya da dizin yok.</translation>
    </message>
    <message>
        <source>The selected key file or directory is not readable.</source>
        <translation>Seçilen anahtar dosyası ya da dizin okunabilir değil.</translation>
    </message>
    <message>
        <source>The given directory does not contain any key files.</source>
        <translation>Verilen dizin bir anahtar dosyası içermiyor.</translation>
    </message>
    <message>
        <source>The given directory contains more then one key files.
Please specify the key file directly.</source>
        <translation>Verilen dizin birden fazla anahtar dosyası içeriyor.
Lütfen anahtar dosyasını belirtin.</translation>
    </message>
    <message>
        <source>%1:
File is not readable.</source>
        <translation>%1:
Dosya okunabilir değil.</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Anahtar Dosyası Oluştur...</translation>
    </message>
</context>
<context>
    <name>PasswordDlg</name>
    <message>
        <source>Last File</source>
        <translation>Son Dosya</translation>
    </message>
    <message>
        <source>Enter a Password and/or choose a key file.</source>
        <translation>Bir parola girin ya da bir anahtar dosyası seçin.</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>&amp;Gözat...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="obsolete">Alt+B</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Anahtar Dosyası:</translation>
    </message>
    <message>
        <source>Generate Key File...</source>
        <translation>Anahtar Dosyası Oluştur...</translation>
    </message>
    <message>
        <source>Please repeat your password:</source>
        <translation>Lütfen parolanızı tekrar girin:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Passwords are not equal.</source>
        <translation>Parolalar aynı değil.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>Search_Dlg</name>
    <message>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation>İçersin:</translation>
    </message>
    <message>
        <source>Pass&amp;words</source>
        <translation>Par&amp;olalar</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+W</translation>
    </message>
    <message>
        <source>A&amp;nhang</source>
        <translation>&amp;Ek</translation>
    </message>
    <message>
        <source>U&amp;RLs</source>
        <translation>A&amp;dresler</translation>
    </message>
    <message>
        <source>Alt+R</source>
        <translation type="obsolete">Alt+R</translation>
    </message>
    <message>
        <source>C&amp;omments</source>
        <translation>A&amp;çıklamalar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Usernames</source>
        <translation>K&amp;ullanıcı Adları</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Titles</source>
        <translation>&amp;Başlıklar</translation>
    </message>
    <message>
        <source>Alt+T</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>&amp;Case Sensitive</source>
        <translation>Bü&amp;yük Küçük Harflere Duyarlı</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Regular E&amp;xpression</source>
        <translation>Düzenli İ&amp;fade</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="obsolete">Alt+X</translation>
    </message>
    <message>
        <source>Include Subgroups (recursive)</source>
        <translation>Alt Grupları İçer (özyinelemeli)</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Şunu Ara:</translation>
    </message>
</context>
<context>
    <name>SelectIconDlg</name>
    <message>
        <source>Icon Selection</source>
        <translation>Simge Seçimi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Show system tray icon</source>
        <translation>Sistem çekmecesi simgesini göster</translation>
    </message>
    <message>
        <source>Minimize to tray instead of taskbar</source>
        <translation>Görev çubuğu yerine sistem çekmecesine küçült</translation>
    </message>
    <message>
        <source>Minimize to tray when clicking the main window&apos;s close button</source>
        <translation type="unfinished">Ana pencere kapatıldığında sistem çekmecesine küçült</translation>
    </message>
    <message>
        <source>Remember last opened file</source>
        <translation>Son açılan dosyayı hatırla</translation>
    </message>
    <message utf8="true">
        <source>Alt+Ö</source>
        <translation type="obsolete">Alt+Ö</translation>
    </message>
    <message>
        <source>Remember last key type and location</source>
        <translation>Son anahtar tipini ve konumunu hatırla</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Küçültülmüş başlat</translation>
    </message>
    <message>
        <source>Start locked</source>
        <translation>Kilitlenmiş başlat</translation>
    </message>
    <message>
        <source>Save recent directories of file dialogs</source>
        <translation>Dosya pencerelerinin son kullanılan dizinlerini kaydet</translation>
    </message>
    <message>
        <source>Clear History Now</source>
        <translation>Geçmişi Şimdi Temizle</translation>
    </message>
    <message>
        <source>Always ask before deleting entries or groups</source>
        <translation>Bir grubu ya da girdiyi silerken her zaman sor</translation>
    </message>
    <message>
        <source>Banner Color</source>
        <translation>Üst Alan Rengi</translation>
    </message>
    <message>
        <source>Text Color:</source>
        <translation>Metin Rengi:</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Değiştir...</translation>
    </message>
    <message>
        <source>Color 2:</source>
        <translation>Renk 2:</translation>
    </message>
    <message>
        <source>C&amp;hange...</source>
        <translation>Deği&amp;ştir...</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="obsolete">Alt+H</translation>
    </message>
    <message>
        <source>Color 1:</source>
        <translation>Renk 1:</translation>
    </message>
    <message>
        <source>Alternating Row Colors</source>
        <translation>Satır Renkleri Farklılaştırılıyor</translation>
    </message>
    <message>
        <source>Customize Entry Detail View...</source>
        <translation>Ayrıntılı Girdi Görünümünü Özelleştir...</translation>
    </message>
    <message>
        <source>Group tree at start-up:</source>
        <translation>Başlangıçta grup ağacı:</translation>
    </message>
    <message>
        <source>Restore last state</source>
        <translation>Son duruma geri dön</translation>
    </message>
    <message>
        <source>Expand all items</source>
        <translation>Tüm ögeleri aç</translation>
    </message>
    <message>
        <source>Do not expand any item</source>
        <translation>Hiçbir ögeyi açma</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Edit Entry Dialog</source>
        <translation>Girdi Düzenleme Penceresi</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Clear clipboard after:</source>
        <translation>Bu süre geçince panoyu temizle:</translation>
    </message>
    <message>
        <source>Lock workspace when minimizing the main window</source>
        <translation>Ana pencereyi küçültürken çalışma alanını kilitle</translation>
    </message>
    <message>
        <source>You can disable several features of KeePassX here according to your needs in order to keep the user interface slim.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Yerimleri</translation>
    </message>
    <message>
        <source>Plug-Ins</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>Gnome Desktop Integration (Gtk 2.x)</source>
        <translation>Gnome Masaüstü Bütünleşmesi (Gtk 2.x)</translation>
    </message>
    <message>
        <source>KDE 4 Desktop Integration</source>
        <translation>KDE4 Masaüstü Bütünleşmesi</translation>
    </message>
    <message>
        <source>You need to restart the program before the changes take effect.</source>
        <translation>Değişikliklerin etkin olabilmesi için uygulamayı yeniden başlatmanız gerekir.</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Yapılandır...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <source>Auto-Type Fine Tuning</source>
        <translation>Otomatik-Tip İyileştirmesi</translation>
    </message>
    <message>
        <source>Time between the activation of an auto-type action by the user and the first simulated key stroke.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Pre-Gap:</source>
        <translation>Pre-Gap:</translation>
    </message>
    <message>
        <source>Key Stroke Delay:</source>
        <translation>Anahtar Gecikmesi:</translation>
    </message>
    <message>
        <source>Delay between two simulated key strokes. Increase this if Auto-Type is randomly skipping characters.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Browser Command</source>
        <translation>Özel Tarayıcı Komutu</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Media Root:</source>
        <translation>Ortam Kök Dizini:</translation>
    </message>
    <message>
        <source>The directory where storage devices like CDs and memory sticks are normally mounted.</source>
        <translation>CD ve bellek çubukları gibi depolama ortamlarının bağlandığı dizin.</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Gözat...</translation>
    </message>
    <message>
        <source>Enable this if you want to use your bookmarks and the last opened file independet from their absolute paths. This is especially useful when using KeePassX portably and therefore with changing mount points in the file system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save relative paths (bookmarks and last file)</source>
        <translation>Değişken yolları kaydet (yer imleri ve son dosyalar)</translation>
    </message>
    <message>
        <source>Global Auto-Type Shortcut:</source>
        <translation>Genel Otomatik-Tip Kısayolu:</translation>
    </message>
    <message>
        <source>Automatically save database on exit and workspace locking</source>
        <translation>Çıkışta veritabanını otomatik olarak kaydet ve çalışma alanını kilitle</translation>
    </message>
    <message>
        <source>Show plain text passwords in:</source>
        <translation>Düz metin parolaları böyle göster:</translation>
    </message>
    <message>
        <source>Database Key Dialog</source>
        <translation>Veritabanı Anahtarı Penceresi</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saniye</translation>
    </message>
    <message>
        <source>Lock database after inactivity of</source>
        <translation>Şu kadar etkinlik olmazsa veritabanını kilitle</translation>
    </message>
    <message>
        <source>Use entries&apos; title to match the window for Global Auto-Type</source>
        <translation>Genel Otomatik Tip için Pencereleri eşlemek amacıyla girdinin başlığını kullan</translation>
    </message>
    <message>
        <source>General (1)</source>
        <translation>Genel (1)</translation>
    </message>
    <message>
        <source>General (2)</source>
        <translation>Genel (2)</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Save backups of modified entries into the &apos;Backup&apos; group</source>
        <translation>Düzenlenen girdileri yedeklemek için &apos;Backup&apos; grubunu kullan</translation>
    </message>
    <message>
        <source>Delete backup entries older than:</source>
        <translation>Bundan eski girdileri sil:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>gün</translation>
    </message>
    <message>
        <source>Automatically save database after every change</source>
        <translation>Her değişiklikte veritabanını otomatik olarak kaydet</translation>
    </message>
    <message>
        <source>System Language</source>
        <translation type="obsolete">Sistem Dili</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">İngilizce</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Dil:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Yazar:</translation>
    </message>
    <message>
        <source>Show window always on top</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutWidget</name>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>AltGr</source>
        <translation>AltGr</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Win</translation>
    </message>
</context>
<context>
    <name>SimplePasswordDialog</name>
    <message>
        <source>Enter your Password</source>
        <translation>Parolanızı Girin</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
</context>
<context>
    <name>TargetWindowDlg</name>
    <message>
        <source>Auto-Type: Select Target Window</source>
        <translation>Otomatik-Tip: Hedef Pencereyi Seçin</translation>
    </message>
    <message>
        <source>To specify the target window, either select an existing currently-opened window
from the drop-down list, or enter the window title manually:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Translation</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation>Serdar Soytetir</translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation>tulliana@gmail.com</translation>
    </message>
    <message>
        <source>$LANGUAGE_NAME</source>
        <comment>Insert your language name in the format: English (United States)</comment>
        <translation>Türkçe</translation>
    </message>
</context>
<context>
    <name>WorkspaceLockedWidget</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;The workspace is locked.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Çalışma alanı kilitli.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>Kilidi Aç</translation>
    </message>
    <message>
        <source>Close Database</source>
        <translation>Veritabanını Kapat</translation>
    </message>
</context>
</TS>
